Skip to contents

Return the path to an example dataset shipped with phiperio, suitable for use with load_example_data or convert_standard.

Usage

get_example_path(name = c("phip_mixture"))

Arguments

name

Character scalar. Name of the example dataset. Currently supported: "phip_mixture".

Value

A character scalar with an absolute path to the file.

Examples

sim_path <- get_example_path("phip_mixture")
# phip_obj <- convert_standard(sim_path)