Return the path to an example dataset shipped with phiperio,
suitable for use with load_example_data or
convert_standard.
Usage
get_example_path(name = c("phip_mixture"))Return the path to an example dataset shipped with phiperio,
suitable for use with load_example_data or
convert_standard.
get_example_path(name = c("phip_mixture"))